# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.dlp_v2.proto import (
    dlp_pb2 as google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DlpServiceStub(object):
    """The Cloud Data Loss Prevention (DLP) API is a service that allows clients
    to detect the presence of Personally Identifiable Information (PII) and other
    privacy-sensitive data in user-supplied, unstructured data streams, like text
    blocks or images.
    The service also includes methods for sensitive data redaction and
    scheduling of data scans on Google Cloud Platform based data sets.

    To learn more about concepts and find how-to guides see
    https://cloud.google.com/dlp/docs/.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
          channel: A grpc.Channel.
        """
        self.InspectContent = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/InspectContent",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectContentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectContentResponse.FromString,
        )
        self.RedactImage = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/RedactImage",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.RedactImageRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.RedactImageResponse.FromString,
        )
        self.DeidentifyContent = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/DeidentifyContent",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyContentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyContentResponse.FromString,
        )
        self.ReidentifyContent = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ReidentifyContent",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ReidentifyContentRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ReidentifyContentResponse.FromString,
        )
        self.ListInfoTypes = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ListInfoTypes",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInfoTypesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInfoTypesResponse.FromString,
        )
        self.CreateInspectTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/CreateInspectTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateInspectTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectTemplate.FromString,
        )
        self.UpdateInspectTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/UpdateInspectTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateInspectTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectTemplate.FromString,
        )
        self.GetInspectTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/GetInspectTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetInspectTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectTemplate.FromString,
        )
        self.ListInspectTemplates = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ListInspectTemplates",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInspectTemplatesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInspectTemplatesResponse.FromString,
        )
        self.DeleteInspectTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/DeleteInspectTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteInspectTemplateRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateDeidentifyTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/CreateDeidentifyTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateDeidentifyTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyTemplate.FromString,
        )
        self.UpdateDeidentifyTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/UpdateDeidentifyTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateDeidentifyTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyTemplate.FromString,
        )
        self.GetDeidentifyTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/GetDeidentifyTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetDeidentifyTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyTemplate.FromString,
        )
        self.ListDeidentifyTemplates = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ListDeidentifyTemplates",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDeidentifyTemplatesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDeidentifyTemplatesResponse.FromString,
        )
        self.DeleteDeidentifyTemplate = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/DeleteDeidentifyTemplate",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteDeidentifyTemplateRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateJobTrigger = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/CreateJobTrigger",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateJobTriggerRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.JobTrigger.FromString,
        )
        self.UpdateJobTrigger = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/UpdateJobTrigger",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateJobTriggerRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.JobTrigger.FromString,
        )
        self.HybridInspectJobTrigger = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/HybridInspectJobTrigger",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectJobTriggerRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectResponse.FromString,
        )
        self.GetJobTrigger = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/GetJobTrigger",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetJobTriggerRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.JobTrigger.FromString,
        )
        self.ListJobTriggers = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ListJobTriggers",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListJobTriggersRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListJobTriggersResponse.FromString,
        )
        self.DeleteJobTrigger = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/DeleteJobTrigger",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteJobTriggerRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ActivateJobTrigger = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ActivateJobTrigger",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ActivateJobTriggerRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DlpJob.FromString,
        )
        self.CreateDlpJob = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/CreateDlpJob",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateDlpJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DlpJob.FromString,
        )
        self.ListDlpJobs = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ListDlpJobs",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDlpJobsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDlpJobsResponse.FromString,
        )
        self.GetDlpJob = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/GetDlpJob",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetDlpJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DlpJob.FromString,
        )
        self.DeleteDlpJob = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/DeleteDlpJob",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteDlpJobRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CancelDlpJob = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/CancelDlpJob",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CancelDlpJobRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateStoredInfoType = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/CreateStoredInfoType",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateStoredInfoTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.StoredInfoType.FromString,
        )
        self.UpdateStoredInfoType = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/UpdateStoredInfoType",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateStoredInfoTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.StoredInfoType.FromString,
        )
        self.GetStoredInfoType = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/GetStoredInfoType",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetStoredInfoTypeRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.StoredInfoType.FromString,
        )
        self.ListStoredInfoTypes = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/ListStoredInfoTypes",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListStoredInfoTypesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListStoredInfoTypesResponse.FromString,
        )
        self.DeleteStoredInfoType = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/DeleteStoredInfoType",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteStoredInfoTypeRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.HybridInspectDlpJob = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/HybridInspectDlpJob",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectDlpJobRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectResponse.FromString,
        )
        self.FinishDlpJob = channel.unary_unary(
            "/google.privacy.dlp.v2.DlpService/FinishDlpJob",
            request_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.FinishDlpJobRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class DlpServiceServicer(object):
    """The Cloud Data Loss Prevention (DLP) API is a service that allows clients
    to detect the presence of Personally Identifiable Information (PII) and other
    privacy-sensitive data in user-supplied, unstructured data streams, like text
    blocks or images.
    The service also includes methods for sensitive data redaction and
    scheduling of data scans on Google Cloud Platform based data sets.

    To learn more about concepts and find how-to guides see
    https://cloud.google.com/dlp/docs/.
    """

    def InspectContent(self, request, context):
        """Finds potentially sensitive info in content.
        This method has limits on input size, processing time, and output size.

        When no InfoTypes or CustomInfoTypes are specified in this request, the
        system will automatically choose what detectors to run. By default this may
        be all types, but may change over time as detectors are updated.

        For how to guides, see https://cloud.google.com/dlp/docs/inspecting-images
        and https://cloud.google.com/dlp/docs/inspecting-text,
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RedactImage(self, request, context):
        """Redacts potentially sensitive info from an image.
        This method has limits on input size, processing time, and output size.
        See https://cloud.google.com/dlp/docs/redacting-sensitive-data-images to
        learn more.

        When no InfoTypes or CustomInfoTypes are specified in this request, the
        system will automatically choose what detectors to run. By default this may
        be all types, but may change over time as detectors are updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeidentifyContent(self, request, context):
        """De-identifies potentially sensitive info from a ContentItem.
        This method has limits on input size and output size.
        See https://cloud.google.com/dlp/docs/deidentify-sensitive-data to
        learn more.

        When no InfoTypes or CustomInfoTypes are specified in this request, the
        system will automatically choose what detectors to run. By default this may
        be all types, but may change over time as detectors are updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ReidentifyContent(self, request, context):
        """Re-identifies content that has been de-identified.
        See
        https://cloud.google.com/dlp/docs/pseudonymization#re-identification_in_free_text_code_example
        to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListInfoTypes(self, request, context):
        """Returns a list of the sensitive information types that the DLP API
        supports. See https://cloud.google.com/dlp/docs/infotypes-reference to
        learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateInspectTemplate(self, request, context):
        """Creates an InspectTemplate for re-using frequently used configuration
        for inspecting content, images, and storage.
        See https://cloud.google.com/dlp/docs/creating-templates to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateInspectTemplate(self, request, context):
        """Updates the InspectTemplate.
        See https://cloud.google.com/dlp/docs/creating-templates to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetInspectTemplate(self, request, context):
        """Gets an InspectTemplate.
        See https://cloud.google.com/dlp/docs/creating-templates to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListInspectTemplates(self, request, context):
        """Lists InspectTemplates.
        See https://cloud.google.com/dlp/docs/creating-templates to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteInspectTemplate(self, request, context):
        """Deletes an InspectTemplate.
        See https://cloud.google.com/dlp/docs/creating-templates to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateDeidentifyTemplate(self, request, context):
        """Creates a DeidentifyTemplate for re-using frequently used configuration
        for de-identifying content, images, and storage.
        See https://cloud.google.com/dlp/docs/creating-templates-deid to learn
        more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateDeidentifyTemplate(self, request, context):
        """Updates the DeidentifyTemplate.
        See https://cloud.google.com/dlp/docs/creating-templates-deid to learn
        more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDeidentifyTemplate(self, request, context):
        """Gets a DeidentifyTemplate.
        See https://cloud.google.com/dlp/docs/creating-templates-deid to learn
        more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListDeidentifyTemplates(self, request, context):
        """Lists DeidentifyTemplates.
        See https://cloud.google.com/dlp/docs/creating-templates-deid to learn
        more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteDeidentifyTemplate(self, request, context):
        """Deletes a DeidentifyTemplate.
        See https://cloud.google.com/dlp/docs/creating-templates-deid to learn
        more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateJobTrigger(self, request, context):
        """Creates a job trigger to run DLP actions such as scanning storage for
        sensitive information on a set schedule.
        See https://cloud.google.com/dlp/docs/creating-job-triggers to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateJobTrigger(self, request, context):
        """Updates a job trigger.
        See https://cloud.google.com/dlp/docs/creating-job-triggers to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HybridInspectJobTrigger(self, request, context):
        """Inspect hybrid content and store findings to a trigger. The inspection
        will be processed asynchronously. To review the findings monitor the
        jobs within the trigger.
        Early access feature is in a pre-release state and might change or have
        limited support. For more information, see
        https://cloud.google.com/products#product-launch-stages.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetJobTrigger(self, request, context):
        """Gets a job trigger.
        See https://cloud.google.com/dlp/docs/creating-job-triggers to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListJobTriggers(self, request, context):
        """Lists job triggers.
        See https://cloud.google.com/dlp/docs/creating-job-triggers to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteJobTrigger(self, request, context):
        """Deletes a job trigger.
        See https://cloud.google.com/dlp/docs/creating-job-triggers to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ActivateJobTrigger(self, request, context):
        """Activate a job trigger. Causes the immediate execute of a trigger
        instead of waiting on the trigger event to occur.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateDlpJob(self, request, context):
        """Creates a new job to inspect storage or calculate risk metrics.
        See https://cloud.google.com/dlp/docs/inspecting-storage and
        https://cloud.google.com/dlp/docs/compute-risk-analysis to learn more.

        When no InfoTypes or CustomInfoTypes are specified in inspect jobs, the
        system will automatically choose what detectors to run. By default this may
        be all types, but may change over time as detectors are updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListDlpJobs(self, request, context):
        """Lists DlpJobs that match the specified filter in the request.
        See https://cloud.google.com/dlp/docs/inspecting-storage and
        https://cloud.google.com/dlp/docs/compute-risk-analysis to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDlpJob(self, request, context):
        """Gets the latest state of a long-running DlpJob.
        See https://cloud.google.com/dlp/docs/inspecting-storage and
        https://cloud.google.com/dlp/docs/compute-risk-analysis to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteDlpJob(self, request, context):
        """Deletes a long-running DlpJob. This method indicates that the client is
        no longer interested in the DlpJob result. The job will be cancelled if
        possible.
        See https://cloud.google.com/dlp/docs/inspecting-storage and
        https://cloud.google.com/dlp/docs/compute-risk-analysis to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CancelDlpJob(self, request, context):
        """Starts asynchronous cancellation on a long-running DlpJob. The server
        makes a best effort to cancel the DlpJob, but success is not
        guaranteed.
        See https://cloud.google.com/dlp/docs/inspecting-storage and
        https://cloud.google.com/dlp/docs/compute-risk-analysis to learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateStoredInfoType(self, request, context):
        """Creates a pre-built stored infoType to be used for inspection.
        See https://cloud.google.com/dlp/docs/creating-stored-infotypes to
        learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateStoredInfoType(self, request, context):
        """Updates the stored infoType by creating a new version. The existing version
        will continue to be used until the new version is ready.
        See https://cloud.google.com/dlp/docs/creating-stored-infotypes to
        learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetStoredInfoType(self, request, context):
        """Gets a stored infoType.
        See https://cloud.google.com/dlp/docs/creating-stored-infotypes to
        learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListStoredInfoTypes(self, request, context):
        """Lists stored infoTypes.
        See https://cloud.google.com/dlp/docs/creating-stored-infotypes to
        learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteStoredInfoType(self, request, context):
        """Deletes a stored infoType.
        See https://cloud.google.com/dlp/docs/creating-stored-infotypes to
        learn more.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HybridInspectDlpJob(self, request, context):
        """Inspect hybrid content and store findings to a job.
        To review the findings inspect the job. Inspection will occur
        asynchronously.
        Early access feature is in a pre-release state and might change or have
        limited support. For more information, see
        https://cloud.google.com/products#product-launch-stages.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def FinishDlpJob(self, request, context):
        """Finish a running hybrid DlpJob. Triggers the finalization steps and running
        of any enabled actions that have not yet run.
        Early access feature is in a pre-release state and might change or have
        limited support. For more information, see
        https://cloud.google.com/products#product-launch-stages.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DlpServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "InspectContent": grpc.unary_unary_rpc_method_handler(
            servicer.InspectContent,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectContentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectContentResponse.SerializeToString,
        ),
        "RedactImage": grpc.unary_unary_rpc_method_handler(
            servicer.RedactImage,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.RedactImageRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.RedactImageResponse.SerializeToString,
        ),
        "DeidentifyContent": grpc.unary_unary_rpc_method_handler(
            servicer.DeidentifyContent,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyContentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyContentResponse.SerializeToString,
        ),
        "ReidentifyContent": grpc.unary_unary_rpc_method_handler(
            servicer.ReidentifyContent,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ReidentifyContentRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ReidentifyContentResponse.SerializeToString,
        ),
        "ListInfoTypes": grpc.unary_unary_rpc_method_handler(
            servicer.ListInfoTypes,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInfoTypesRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInfoTypesResponse.SerializeToString,
        ),
        "CreateInspectTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.CreateInspectTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateInspectTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectTemplate.SerializeToString,
        ),
        "UpdateInspectTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateInspectTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateInspectTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectTemplate.SerializeToString,
        ),
        "GetInspectTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.GetInspectTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetInspectTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.InspectTemplate.SerializeToString,
        ),
        "ListInspectTemplates": grpc.unary_unary_rpc_method_handler(
            servicer.ListInspectTemplates,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInspectTemplatesRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListInspectTemplatesResponse.SerializeToString,
        ),
        "DeleteInspectTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteInspectTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteInspectTemplateRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateDeidentifyTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.CreateDeidentifyTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateDeidentifyTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyTemplate.SerializeToString,
        ),
        "UpdateDeidentifyTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateDeidentifyTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateDeidentifyTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyTemplate.SerializeToString,
        ),
        "GetDeidentifyTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.GetDeidentifyTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetDeidentifyTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeidentifyTemplate.SerializeToString,
        ),
        "ListDeidentifyTemplates": grpc.unary_unary_rpc_method_handler(
            servicer.ListDeidentifyTemplates,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDeidentifyTemplatesRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDeidentifyTemplatesResponse.SerializeToString,
        ),
        "DeleteDeidentifyTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteDeidentifyTemplate,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteDeidentifyTemplateRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateJobTrigger": grpc.unary_unary_rpc_method_handler(
            servicer.CreateJobTrigger,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateJobTriggerRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.JobTrigger.SerializeToString,
        ),
        "UpdateJobTrigger": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateJobTrigger,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateJobTriggerRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.JobTrigger.SerializeToString,
        ),
        "HybridInspectJobTrigger": grpc.unary_unary_rpc_method_handler(
            servicer.HybridInspectJobTrigger,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectJobTriggerRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectResponse.SerializeToString,
        ),
        "GetJobTrigger": grpc.unary_unary_rpc_method_handler(
            servicer.GetJobTrigger,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetJobTriggerRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.JobTrigger.SerializeToString,
        ),
        "ListJobTriggers": grpc.unary_unary_rpc_method_handler(
            servicer.ListJobTriggers,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListJobTriggersRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListJobTriggersResponse.SerializeToString,
        ),
        "DeleteJobTrigger": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteJobTrigger,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteJobTriggerRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ActivateJobTrigger": grpc.unary_unary_rpc_method_handler(
            servicer.ActivateJobTrigger,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ActivateJobTriggerRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DlpJob.SerializeToString,
        ),
        "CreateDlpJob": grpc.unary_unary_rpc_method_handler(
            servicer.CreateDlpJob,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateDlpJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DlpJob.SerializeToString,
        ),
        "ListDlpJobs": grpc.unary_unary_rpc_method_handler(
            servicer.ListDlpJobs,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDlpJobsRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListDlpJobsResponse.SerializeToString,
        ),
        "GetDlpJob": grpc.unary_unary_rpc_method_handler(
            servicer.GetDlpJob,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetDlpJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DlpJob.SerializeToString,
        ),
        "DeleteDlpJob": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteDlpJob,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteDlpJobRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CancelDlpJob": grpc.unary_unary_rpc_method_handler(
            servicer.CancelDlpJob,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CancelDlpJobRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateStoredInfoType": grpc.unary_unary_rpc_method_handler(
            servicer.CreateStoredInfoType,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.CreateStoredInfoTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.StoredInfoType.SerializeToString,
        ),
        "UpdateStoredInfoType": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateStoredInfoType,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.UpdateStoredInfoTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.StoredInfoType.SerializeToString,
        ),
        "GetStoredInfoType": grpc.unary_unary_rpc_method_handler(
            servicer.GetStoredInfoType,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.GetStoredInfoTypeRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.StoredInfoType.SerializeToString,
        ),
        "ListStoredInfoTypes": grpc.unary_unary_rpc_method_handler(
            servicer.ListStoredInfoTypes,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListStoredInfoTypesRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.ListStoredInfoTypesResponse.SerializeToString,
        ),
        "DeleteStoredInfoType": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteStoredInfoType,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.DeleteStoredInfoTypeRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "HybridInspectDlpJob": grpc.unary_unary_rpc_method_handler(
            servicer.HybridInspectDlpJob,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectDlpJobRequest.FromString,
            response_serializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.HybridInspectResponse.SerializeToString,
        ),
        "FinishDlpJob": grpc.unary_unary_rpc_method_handler(
            servicer.FinishDlpJob,
            request_deserializer=google_dot_cloud_dot_dlp__v2_dot_proto_dot_dlp__pb2.FinishDlpJobRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.privacy.dlp.v2.DlpService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
